import os
import importlib
import subprocess
import sys
import logging
import discord
from discord.ext import commands

# Auto-installation des dépendances
def install_requirements():
    required_packages = ["requests", "discord"]
    for package in required_packages:
        try:
            __import__(package)
        except ImportError:
            print(f"Installation de '{package}' en cours...")
            subprocess.check_call([sys.executable, "-m", "pip", "install", package])

install_requirements()

# Configuration du logger
logging.basicConfig(level=logging.INFO, format='%(asctime)s - %(levelname)s - %(message)s')

class FeegaffeBot:
    def __init__(self, command_prefix: str = "!", intents=None):
        if intents is None:
            intents = discord.Intents.all()
        self.bot = commands.Bot(command_prefix=command_prefix, intents=intents)
        self.load_commands()
        
        @self.bot.event
        async def on_ready():
            logging.info(f'✅ Connecté en tant que {self.bot.user}')
        
        @self.bot.event
        async def on_message(message):
            if message.author.bot:
                return  # Ignore les messages des bots
            logging.info(f"[{message.author}] {message.content}")
            await self.bot.process_commands(message)  # Permet de traiter les commandes
        
        @self.bot.event
        async def on_member_join(member):
            channel = member.guild.system_channel
            if channel:
                await channel.send(f"Bienvenue {member.mention} sur {member.guild.name} !")

    def load_commands(self):
        """Charge automatiquement toutes les commandes du dossier 'commands'."""
        if not os.path.exists("commands"):
            os.makedirs("commands")

        for filename in os.listdir("commands"):
            if filename.endswith(".py"):
                module_name = f"commands.{filename[:-3]}"
                try:
                    importlib.import_module(module_name)
                    logging.info(f"✅ Commande chargée : {filename[:-3]}")
                except Exception as e:
                    logging.error(f"❌ Erreur de chargement {filename}: {e}")
    
    def command(self, *args, **kwargs):
        return self.bot.command(*args, **kwargs)

    def run(self, token: str):
        """Lance le bot avec le token Discord."""
        self.bot.run(token)

# Interface simple pour récupérer le bot

def bot(command_prefix: str = "!"):
    feegaffe = FeegaffeBot(command_prefix)
    return feegaffe.bot